"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts = require("typescript");
const loader_1 = require("./loader");
const compiler_host_1 = require("./compiler_host");
const refactor_1 = require("./refactor");
describe('@ngtools/webpack', () => {
    describe('loader', () => {
        describe('removeModuleId', () => {
            it('should work', () => {
                const host = new compiler_host_1.WebpackCompilerHost({}, '');
                host.writeFile('/file.ts', `
          export const obj = { moduleId: 123 };
          export const obj2 = { moduleId: 123, otherValue: 1 };
          export const obj3 = { otherValue: 1, moduleId: 123 };
        `, false);
                host.writeFile('/file2.ts', `
          @SomeDecorator({ moduleId: 123 }) class CLS {}
          @SomeDecorator({ moduleId: 123, otherValue1: 1 }) class CLS2 {}
          @SomeDecorator({ otherValue2: 2, moduleId: 123, otherValue3: 3 }) class CLS3 {}
          @SomeDecorator({ otherValue4: 4, moduleId: 123 }) class CLS4 {}
        `, false);
                const program = ts.createProgram(['/file.ts', '/file2.ts'], {}, host);
                const refactor = new refactor_1.TypeScriptFileRefactor('/file.ts', host, program);
                loader_1.removeModuleIdOnlyForTesting(refactor);
                expect(refactor.sourceText).not.toMatch(/obj = \{\s+};/);
                expect(refactor.sourceText).not.toMatch(/\{\s*otherValue: 1\s*};/);
                const refactor2 = new refactor_1.TypeScriptFileRefactor('/file2.ts', host, program);
                loader_1.removeModuleIdOnlyForTesting(refactor2);
                expect(refactor2.sourceText).toMatch(/\(\{\s+}\)/);
                expect(refactor2.sourceText).toMatch(/\(\{\s*otherValue1: 1\s*}\)/);
                expect(refactor2.sourceText).toMatch(/\(\{\s*otherValue2: 2\s*,\s*otherValue3: 3\s*}\)/);
                expect(refactor2.sourceText).toMatch(/\(\{\s*otherValue4: 4\s*}\)/);
            });
            it('should work without a root name', () => {
                const host = new compiler_host_1.WebpackCompilerHost({}, '');
                host.writeFile('/file.ts', `
          import './file2.ts';
        `, false);
                host.writeFile('/file2.ts', `
          @SomeDecorator({ moduleId: 123 }) class CLS {}
          @SomeDecorator({ moduleId: 123, otherValue1: 1 }) class CLS2 {}
          @SomeDecorator({ otherValue2: 2, moduleId: 123, otherValue3: 3 }) class CLS3 {}
          @SomeDecorator({ otherValue4: 4, moduleId: 123 }) class CLS4 {}
        `, false);
                const program = ts.createProgram(['/file.ts'], {}, host);
                const refactor = new refactor_1.TypeScriptFileRefactor('/file2.ts', host, program);
                loader_1.removeModuleIdOnlyForTesting(refactor);
                expect(refactor.sourceText).toMatch(/\(\{\s+}\)/);
                expect(refactor.sourceText).toMatch(/\(\{\s*otherValue1: 1\s*}\)/);
                expect(refactor.sourceText).toMatch(/\(\{\s*otherValue2: 2\s*,\s*otherValue3: 3\s*}\)/);
                expect(refactor.sourceText).toMatch(/\(\{\s*otherValue4: 4\s*}\)/);
            });
        });
    });
});
//# sourceMappingURL=/users/dan/projects/angular-cli/src/loader.spec.js.map