"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_tags_1 = require("common-tags");
const ast_helpers_1 = require("./ast_helpers");
const export_lazy_module_map_1 = require("./export_lazy_module_map");
describe('@ngtools/webpack transformers', () => {
    describe('export_lazy_module_map', () => {
        it('should create module map for JIT', () => {
            const input = common_tags_1.stripIndent `
        export { AppModule } from './app/app.module';
      `;
            // tslint:disable:max-line-length
            const output = common_tags_1.stripIndent `
        import * as __lazy_0__ from "app/lazy/lazy.module.ts";
        import * as __lazy_1__ from "app/lazy2/lazy2.module.ts";
        export { AppModule } from './app/app.module';
        export var LAZY_MODULE_MAP = { "./lazy/lazy.module#LazyModule": __lazy_0__.LazyModule, "./lazy2/lazy2.module#LazyModule2": __lazy_1__.LazyModule2 };
      `;
            // tslint:enable:max-line-length
            const transformer = export_lazy_module_map_1.exportLazyModuleMap(() => true, () => ({
                './lazy/lazy.module#LazyModule': '/project/src/app/lazy/lazy.module.ts',
                './lazy2/lazy2.module#LazyModule2': '/project/src/app/lazy2/lazy2.module.ts',
            }));
            const result = ast_helpers_1.transformTypescript(input, [transformer]);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${output}`);
        });
        it('should create module map for AOT', () => {
            const input = common_tags_1.stripIndent `
      export { AppModule } from './app/app.module';
    `;
            // tslint:disable:max-line-length
            const expected = common_tags_1.stripIndent `
      import * as __lazy_0__ from "app/lazy/lazy.module.ngfactory.ts";
      import * as __lazy_1__ from "app/lazy2/lazy2.module.ngfactory.ts";
      export { AppModule } from './app/app.module';
      export var LAZY_MODULE_MAP = { "./lazy/lazy.module#LazyModule": __lazy_0__.LazyModuleNgFactory, "./lazy2/lazy2.module#LazyModule2": __lazy_1__.LazyModule2NgFactory };
    `;
            // tslint:enable:max-line-length
            const transformer = export_lazy_module_map_1.exportLazyModuleMap(() => true, () => ({
                './lazy/lazy.module.ngfactory#LazyModuleNgFactory': '/project/src/app/lazy/lazy.module.ngfactory.ts',
                './lazy2/lazy2.module.ngfactory#LazyModule2NgFactory': '/project/src/app/lazy2/lazy2.module.ngfactory.ts',
            }));
            const result = ast_helpers_1.transformTypescript(input, [transformer]);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${expected}`);
        });
    });
    it('should not do anything if shouldTransform returns false', () => {
        const input = common_tags_1.stripIndent `
        export { AppModule } from './app/app.module';
      `;
        const transformer = export_lazy_module_map_1.exportLazyModuleMap(() => false, () => ({
            './lazy/lazy.module#LazyModule': '/project/src/app/lazy/lazy.module.ts',
            './lazy2/lazy2.module#LazyModule2': '/project/src/app/lazy2/lazy2.module.ts',
        }));
        const result = ast_helpers_1.transformTypescript(input, [transformer]);
        expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${input}`);
    });
});
//# sourceMappingURL=/users/dan/projects/angular-cli/src/transformers/export_lazy_module_map.spec.js.map