"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_tags_1 = require("common-tags");
const ast_helpers_1 = require("./ast_helpers");
const export_ngfactory_1 = require("./export_ngfactory");
describe('@ngtools/webpack transformers', () => {
    describe('export_ngfactory', () => {
        it('should export the ngfactory', () => {
            const input = common_tags_1.stripIndent `
        export { AppModule } from './app/app.module';
      `;
            const output = common_tags_1.stripIndent `
        export { AppModuleNgFactory } from "./app/app.module.ngfactory";
        export { AppModule } from './app/app.module';
      `;
            const transformer = export_ngfactory_1.exportNgFactory(() => true, () => ({ path: '/project/src/app/app.module', className: 'AppModule' }));
            const result = ast_helpers_1.transformTypescript(input, [transformer]);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${output}`);
        });
        it('should export the ngfactory when there is a barrel file', () => {
            const input = common_tags_1.stripIndent `
        export { AppModule } from './app';
      `;
            const output = common_tags_1.stripIndent `
        export { AppModuleNgFactory } from "./app/app.module.ngfactory";
        export { AppModule } from './app';
      `;
            const transformer = export_ngfactory_1.exportNgFactory(() => true, () => ({ path: '/project/src/app/app.module', className: 'AppModule' }));
            const result = ast_helpers_1.transformTypescript(input, [transformer]);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${output}`);
        });
        it('should not do anything if shouldTransform returns false', () => {
            const input = common_tags_1.stripIndent `
        export { AppModule } from './app/app.module';
      `;
            const transformer = export_ngfactory_1.exportNgFactory(() => false, () => ({ path: '/project/src/app/app.module', className: 'AppModule' }));
            const result = ast_helpers_1.transformTypescript(input, [transformer]);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${input}`);
        });
    });
});
//# sourceMappingURL=/users/dan/projects/angular-cli/src/transformers/export_ngfactory.spec.js.map