"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_tags_1 = require("common-tags");
const ast_helpers_1 = require("./ast_helpers");
const replace_bootstrap_1 = require("./replace_bootstrap");
const export_ngfactory_1 = require("./export_ngfactory");
const export_lazy_module_map_1 = require("./export_lazy_module_map");
const remove_decorators_1 = require("./remove_decorators");
describe('@ngtools/webpack transformers', () => {
    describe('multiple_transformers', () => {
        it('should apply multiple transformers on the same file', () => {
            const input = common_tags_1.stripIndent `
        import { enableProdMode } from '@angular/core';
        import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
        import { Component } from '@angular/core';

        import { AppModule } from './app/app.module';
        import { environment } from './environments/environment';

        @Component({
          selector: 'app-root',
          templateUrl: './app.component.html',
          styleUrls: ['./app.component.css']
        })
        class AppComponent {
          title = 'app';
        }

        if (environment.production) {
          enableProdMode();
        }

        platformBrowserDynamic().bootstrapModule(AppModule);
      `;
            // tslint:disable:max-line-length
            const output = common_tags_1.stripIndent `
        import * as __lazy_0__ from "app/lazy/lazy.module.ngfactory.ts";
        import * as __lazy_1__ from "app/lazy2/lazy2.module.ngfactory.ts";

        import { enableProdMode } from '@angular/core';
        import { environment } from './environments/environment';

        import * as __NgCli_bootstrap_1 from "./app/app.module.ngfactory";
        import * as __NgCli_bootstrap_2 from "@angular/platform-browser";

        class AppComponent {
          constructor() { this.title = 'app'; }
        }

        if (environment.production) {
          enableProdMode();
        }
        __NgCli_bootstrap_2.platformBrowser().bootstrapModuleFactory(__NgCli_bootstrap_1.AppModuleNgFactory);

        export var LAZY_MODULE_MAP = { "./lazy/lazy.module#LazyModule": __lazy_0__.LazyModuleNgFactory, "./lazy2/lazy2.module#LazyModule2": __lazy_1__.LazyModule2NgFactory };
      `;
            // tslint:enable:max-line-length
            const { program, compilerHost } = ast_helpers_1.createTypescriptContext(input);
            const shouldTransform = () => true;
            const getEntryModule = () => ({ path: '/project/src/app/app.module', className: 'AppModule' });
            const getTypeChecker = () => program.getTypeChecker();
            const transformers = [
                replace_bootstrap_1.replaceBootstrap(shouldTransform, getEntryModule, getTypeChecker),
                export_ngfactory_1.exportNgFactory(shouldTransform, getEntryModule),
                export_lazy_module_map_1.exportLazyModuleMap(shouldTransform, () => ({
                    './lazy/lazy.module.ngfactory#LazyModuleNgFactory': '/project/src/app/lazy/lazy.module.ngfactory.ts',
                    './lazy2/lazy2.module.ngfactory#LazyModule2NgFactory': '/project/src/app/lazy2/lazy2.module.ngfactory.ts',
                })),
                remove_decorators_1.removeDecorators(shouldTransform, getTypeChecker),
            ];
            const result = ast_helpers_1.transformTypescript(undefined, transformers, program, compilerHost);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${output}`);
        });
    });
});
//# sourceMappingURL=/users/dan/projects/angular-cli/src/transformers/multiple_transformers.spec.js.map