"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_tags_1 = require("common-tags");
const ast_helpers_1 = require("./ast_helpers");
const register_locale_data_1 = require("./register_locale_data");
describe('@ngtools/webpack transformers', () => {
    describe('register_locale_data', () => {
        it('should add locale imports', () => {
            const input = common_tags_1.stripIndent `
        import { enableProdMode } from '@angular/core';
        import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';

        import { AppModule } from './app/app.module';
        import { environment } from './environments/environment';

        if (environment.production) {
          enableProdMode();
        }

        platformBrowserDynamic().bootstrapModule(AppModule);
      `;
            const output = common_tags_1.stripIndent `
        import * as __NgCli_locale_1 from "@angular/common/locales/fr";
        import * as __NgCli_locale_2 from "@angular/common";
        __NgCli_locale_2.registerLocaleData(__NgCli_locale_1.default);

        import { enableProdMode } from '@angular/core';
        import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';

        import { AppModule } from './app/app.module';
        import { environment } from './environments/environment';

        if (environment.production) {
            enableProdMode();
        }

        platformBrowserDynamic().bootstrapModule(AppModule);
      `;
            const transformer = register_locale_data_1.registerLocaleData(() => true, () => ({ path: '/project/src/app/app.module', className: 'AppModule' }), 'fr');
            const result = ast_helpers_1.transformTypescript(input, [transformer]);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${output}`);
        });
        it('should not add locale imports when there is no entry module', () => {
            const input = common_tags_1.stripIndent `
        import { enableProdMode } from '@angular/core';
        import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';

        import { AppModule } from './app/app.module';
        import { environment } from './environments/environment';

        if (environment.production) {
          enableProdMode();
        }

        platformBrowserDynamic().bootstrapModule(AppModule);
      `;
            const transformer = register_locale_data_1.registerLocaleData(() => true, () => undefined, 'fr');
            const result = ast_helpers_1.transformTypescript(input, [transformer]);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${input}`);
        });
    });
});
//# sourceMappingURL=/users/dan/projects/angular-cli/src/transformers/register_locale_data.spec.js.map