"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_tags_1 = require("common-tags");
const ast_helpers_1 = require("./ast_helpers");
const replace_bootstrap_1 = require("./replace_bootstrap");
describe('@ngtools/webpack transformers', () => {
    describe('replace_bootstrap', () => {
        it('should replace bootstrap', () => {
            const input = common_tags_1.stripIndent `
        import { enableProdMode } from '@angular/core';
        import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';

        import { AppModule } from './app/app.module';
        import { environment } from './environments/environment';

        if (environment.production) {
          enableProdMode();
        }

        platformBrowserDynamic().bootstrapModule(AppModule);
      `;
            // tslint:disable:max-line-length
            const output = common_tags_1.stripIndent `
        import { enableProdMode } from '@angular/core';
        import { environment } from './environments/environment';

        import * as __NgCli_bootstrap_1 from "./app/app.module.ngfactory";
        import * as __NgCli_bootstrap_2 from "@angular/platform-browser";

        if (environment.production) {
          enableProdMode();
        }
        __NgCli_bootstrap_2.platformBrowser().bootstrapModuleFactory(__NgCli_bootstrap_1.AppModuleNgFactory);
      `;
            // tslint:enable:max-line-length
            const { program, compilerHost } = ast_helpers_1.createTypescriptContext(input);
            const transformer = replace_bootstrap_1.replaceBootstrap(() => true, () => ({ path: '/project/src/app/app.module', className: 'AppModule' }), () => program.getTypeChecker());
            const result = ast_helpers_1.transformTypescript(undefined, [transformer], program, compilerHost);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${output}`);
        });
        it('should replace bootstrap when barrel files are used', () => {
            const input = common_tags_1.stripIndent `
        import { enableProdMode } from '@angular/core';
        import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';

        import { AppModule } from './app';
        import { environment } from './environments/environment';

        if (environment.production) {
          enableProdMode();
        }

        platformBrowserDynamic().bootstrapModule(AppModule);
      `;
            // tslint:disable:max-line-length
            const output = common_tags_1.stripIndent `
        import { enableProdMode } from '@angular/core';
        import { environment } from './environments/environment';

        import * as __NgCli_bootstrap_1 from "./app/app.module.ngfactory";
        import * as __NgCli_bootstrap_2 from "@angular/platform-browser";

        if (environment.production) {
          enableProdMode();
        }
        __NgCli_bootstrap_2.platformBrowser().bootstrapModuleFactory(__NgCli_bootstrap_1.AppModuleNgFactory);
      `;
            // tslint:enable:max-line-length
            const { program, compilerHost } = ast_helpers_1.createTypescriptContext(input);
            const transformer = replace_bootstrap_1.replaceBootstrap(() => true, () => ({ path: '/project/src/app/app.module', className: 'AppModule' }), () => program.getTypeChecker());
            const result = ast_helpers_1.transformTypescript(undefined, [transformer], program, compilerHost);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${output}`);
        });
        it('should not replace bootstrap when there is no entry module', () => {
            const input = common_tags_1.stripIndent `
        import { enableProdMode } from '@angular/core';
        import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';

        import { AppModule } from './app/app.module';
        import { environment } from './environments/environment';

        if (environment.production) {
          enableProdMode();
        }

        platformBrowserDynamic().bootstrapModule(AppModule);
      `;
            const { program, compilerHost } = ast_helpers_1.createTypescriptContext(input);
            const transformer = replace_bootstrap_1.replaceBootstrap(() => true, () => undefined, () => program.getTypeChecker());
            const result = ast_helpers_1.transformTypescript(undefined, [transformer], program, compilerHost);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${input}`);
        });
    });
});
//# sourceMappingURL=/users/dan/projects/angular-cli/src/transformers/replace_bootstrap.spec.js.map