"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_tags_1 = require("common-tags");
const ast_helpers_1 = require("./ast_helpers");
const replace_resources_1 = require("./replace_resources");
describe('@ngtools/webpack transformers', () => {
    describe('replace_resources', () => {
        it('should replace resources', () => {
            const input = common_tags_1.stripIndent `
        import { Component } from '@angular/core';

        @Component({
          selector: 'app-root',
          templateUrl: './app.component.html',
          styleUrls: ['./app.component.css', './app.component.2.css']
        })
        export class AppComponent {
          title = 'app';
        }
      `;
            const output = common_tags_1.stripIndent `
        import * as tslib_1 from "tslib";
        import { Component } from '@angular/core';
        let AppComponent = class AppComponent {
            constructor() {
                this.title = 'app';
            }
        };
        AppComponent = tslib_1.__decorate([
            Component({
                selector: 'app-root',
                template: require("./app.component.html"),
                styles: [require("./app.component.css"), require("./app.component.2.css")]
            })
        ], AppComponent);
        export { AppComponent };
      `;
            const transformer = replace_resources_1.replaceResources(() => true);
            const result = ast_helpers_1.transformTypescript(input, [transformer]);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${output}`);
        });
        it('should not replace resources if shouldTransform returns false', () => {
            const input = common_tags_1.stripIndent `
        import { Component } from '@angular/core';

        @Component({
          selector: 'app-root',
          templateUrl: './app.component.html',
          styleUrls: ['./app.component.css', './app.component.2.css']
        })
        export class AppComponent {
          title = 'app';
        }
      `;
            const output = `
        import * as tslib_1 from "tslib";
        import { Component } from '@angular/core';
        let AppComponent = class AppComponent {
            constructor() {
                this.title = 'app';
            }
        };
        AppComponent = tslib_1.__decorate([
            Component({
                selector: 'app-root',
                templateUrl: './app.component.html',
                styleUrls: ['./app.component.css', './app.component.2.css']
            })
        ], AppComponent);
        export { AppComponent };
      `;
            const transformer = replace_resources_1.replaceResources(() => false);
            const result = ast_helpers_1.transformTypescript(input, [transformer]);
            expect(common_tags_1.oneLine `${result}`).toEqual(common_tags_1.oneLine `${output}`);
        });
    });
});
//# sourceMappingURL=/users/dan/projects/angular-cli/src/transformers/replace_resources.spec.js.map